@@ -1,5 +1,5 @@
 """
-constants
+Constants
 """
 
 from django.utils.text import slugify
@@ -21,7 +21,13 @@ SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE = _(
     "Request-Code with your inquiry."
 )
 
+# zKillboard - https://zkillboard.com/
 ZKILLBOARD_BASE_URL = "https://zkillboard.com/"
 ZKILLBOARD_API_URL = "https://zkillboard.com/api/"
-ZKILLBOARD_BASE_URL_REGEX = r"^http[s]?://zkillboard\.com/"
-ZKILLBOAR_KILLMAIL_URL_REGEX = r"^http[s]?://zkillboard\.com/kill/\d+\/"
+ZKILLBOARD_BASE_URL_REGEX = r"^http[s]?:\/\/zkillboard\.com\/"
+ZKILLBOARD_KILLMAIL_URL_REGEX = r"^http[s]?:\/\/zkillboard\.com\/kill\/\d+\/"
+
+# EveTools Killboard - https://kb.evetools.org/
+EVETOOLS_KILLBOARD_BASE_URL = "https://kb.evetools.org/"
+EVETOOLS_KILLBOARD_BASE_URL_REGEX = r"^http[s]?:\/\/kb\.evetools\.org\/"
+EVETOOLS_KILLBOARD_KILLMAIL_URL_REGEX = r"^http[s]?:\/\/kb\.evetools\.org\/kill\/\d+"
